@@ -20,6 +20,7 @@ class WorkflowProperty(BaseProperty):
         """
         super().__init__(name, parser, *args, **kwargs)
         self.name = name
+        self.display_name = name
 
     @property
     def schema(self):
@@ -33,6 +34,7 @@ class WorkflowProperty(BaseProperty):
     def common_config(self) -> dict:
         config = {
             "name": self.name,
+            "displayName": self.display_name,
             "creator": {
                 "_id": "",
                 "cls": "User",
@@ -109,6 +111,7 @@ class PyMLTrainAndPredictWorkflow(WorkflowProperty):
         self.object_storage_data = object_storage_data
         self.context_dir_relative_path = context_dir_relative_path
         self.workflow = copy.deepcopy(workflow)
+        self.display_name = f"[Predict Workflow] {self.workflow['name']}"
 
     def _create_download_from_object_storage_input(self, basename: str) -> dict:
         """
